# nekos.py
A Python module that uses Nekos API

## Requirements
- Python 3.6 and up - https://www.python.org/downloads/

# Install
```
pip install nekos.py
```

# Usage example
```py
import nekos
print(nekos.cat())

>>> 'https://cdn.nekos.life/meow/04D5A.jpg'
```

# Endpoints
NOTE: You must call them as functions
- cat
- eightball
- fact
- img
- owoify
- textcat
- why
